@@ -1,6 +1,6 @@
 package ExtUtils::Helpers::Windows;
 {
-  $ExtUtils::Helpers::Windows::VERSION = '0.018';
+  $ExtUtils::Helpers::Windows::VERSION = '0.019';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -9,13 +9,14 @@ use Exporter 5.57 'import';
 our @EXPORT = qw/make_executable split_like_shell detildefy/;
 
 use Config;
+use Carp qw/carp croak/;
 
 sub make_executable {
 	my $script = shift;
-	if (-T $script && $script !~ /\.(bat|cmd)$/) {
+	if (-T $script && $script !~ / \. (?:bat|cmd) $ /x) {
 		my $out = eval { _pl2bat(in => $script, update => 1) };
 		if ($@) {
-			warn "WARNING: Unable to convert file '$script' to an executable script:\n$@";
+			carp "WARNING: Unable to convert file '$script' to an executable script:\n$@";
 		}
 	}
 	return;
@@ -29,51 +30,51 @@ sub _pl2bat {
 	my %opts = @_;
 
 	# NOTE: %0 is already enclosed in doublequotes by cmd.exe, as appropriate
-	$opts{ntargs}	 = '-x -S %0 %*';
+	$opts{ntargs}    = '-x -S %0 %*';
 	$opts{otherargs} = '-x -S "%0" %1 %2 %3 %4 %5 %6 %7 %8 %9';
 
 	$opts{stripsuffix} = qr/\.plx?/ unless exists $opts{stripsuffix};
 
-	unless (exists $opts{out}) {
+	if (not exists $opts{out}) {
 		$opts{out} = $opts{in};
 		$opts{out} =~ s/$opts{stripsuffix}$//i;
-		$opts{out} .= '.bat' unless $opts{in} =~ /\.bat$/i or $opts{in} =~ /^-$/;
+		$opts{out} .= '.bat' unless $opts{in} =~ /\.bat$/i or $opts{in} eq '-';
 	}
 
-  my $head = <<EOT;
-    \@rem = '--*-Perl-*--
-    \@echo off
-    if "%OS%" == "Windows_NT" goto WinNT
-    perl $opts{otherargs}
+	my $head = <<"EOT";
+	\@rem = '--*-Perl-*--
+	\@echo off
+	if "%OS%" == "Windows_NT" goto WinNT
+	perl $opts{otherargs}
 	\@set ErrorLevel=%ErrorLevel%
-    goto endofperl
-    :WinNT
-    perl $opts{ntargs}
+	goto endofperl
+	:WinNT
+	perl $opts{ntargs}
 	\@set ErrorLevel=%ErrorLevel%
-    if NOT "%COMSPEC%" == "%SystemRoot%\\system32\\cmd.exe" goto endofperl
-    if %errorlevel% == 9009 echo You do not have Perl in your PATH.
-    goto endofperl
-    \@rem ';
+	if NOT "%COMSPEC%" == "%SystemRoot%\\system32\\cmd.exe" goto endofperl
+	if %errorlevel% == 9009 echo You do not have Perl in your PATH.
+	goto endofperl
+	\@rem ';
 EOT
 
 	$head =~ s/^\s+//gm;
 	my $headlines = 2 + ($head =~ tr/\n/\n/);
-	my $tail = <<EOT;
+	my $tail = <<'EOT';
 	__END__
 	:endofperl
 	@"%COMSPEC%" /c exit /b %ErrorLevel%
 EOT
 	$tail =~ s/^\s+//gm;
 
-	my $linedone	= 0;
-	my $taildone	= 0;
-	my $linenum	 = 0;
+	my $linedone = 0;
+	my $taildone = 0;
+	my $linenum = 0;
 	my $skiplines = 0;
 
 	my $start = $Config{startperl};
-	$start = "#!perl" unless $start =~ /^#!.*perl/;
+	$start = '#!perl' unless $start =~ /^#!.*perl/;
 
-	open my $in, '<', $opts{in} or die "Can't open $opts{in}: $!";
+	open my $in, '<', $opts{in} or croak "Can't open $opts{in}: $!";
 	my @file = <$in>;
 	close $in;
 
@@ -89,20 +90,20 @@ EOT
 		if ( not $linedone and $line =~ /^#!.*perl/ ) {
 			if (exists $opts{update}) {
 				$skiplines = $linenum - 1;
-				$line .= "#line ".(1+$headlines)."\n";
+				$line .= '#line '.(1+$headlines)."\n";
 			} else {
-	$line .= "#line ".($linenum+$headlines)."\n";
+	$line .= '#line '.($linenum+$headlines)."\n";
 			}
 	$linedone++;
 		}
 		if ( $line =~ /^#\s*line\b/ and $linenum == 2 + $skiplines ) {
-			$line = "";
+			$line = '';
 		}
 	}
 
-	open my $out, '>', $opts{out} or die or die "Can't open $opts{out}: $!";
+	open my $out, '>', $opts{out} or croak "Can't open $opts{out}: $!";
 	print $out $head;
-	print $out $start, ( $opts{usewarnings} ? " -w" : "" ),
+	print $out $start, ( $opts{usewarnings} ? ' -w' : '' ),
 						 "\n#line ", ($headlines+1), "\n" unless $linedone;
 	print $out @file[$skiplines..$#file];
 	print $out $tail unless $taildone;
@@ -130,7 +131,7 @@ sub split_like_shell {
 
 	while ( $i < length ) {
 
-		my $ch			= substr $_, $i	, 1;
+		my $ch      = substr $_, $i, 1;
 		my $next_ch = substr $_, $i+1, 1;
 
 		if ( $ch eq '\\' && $next_ch eq '"' ) {
@@ -144,8 +145,7 @@ sub split_like_shell {
 			$arg .= '"';
 			$i++;
 		} elsif ( $ch eq '"' && $next_ch eq '"' && !$quote_mode &&
-				( $i + 2 == length()	||
-		substr( $_, $i + 2, 1 ) eq ' ' )
+				( $i + 2 == length() || substr( $_, $i + 2, 1 ) eq ' ' )
 			) { # for cases like: a"" => [ 'a' ]
 			push @argv, $arg;
 			$arg = '';
@@ -187,7 +187,7 @@ ExtUtils::Helpers::Windows - Windows specific helper bits
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =for Pod::Coverage make_executable
 split_like_shell
